/* GCC */

#include <cstdio>
#include <algorithm>
#include <stdint.h>
#include <vector>

using namespace std;

typedef int64_t i64;

struct Point {
    int x, y;
    Point() : x(0), y(0) {}
    Point(int x, int y) : x(x), y(y) {}
    i64 length() const
    {
        return (i64)x*x + (i64)y*y;
    }
};

Point operator-(Point l, Point r)
{
    return Point(l.x-r.x, l.y-r.y);
}
int operator^(Point l, Point r)
{
    return l.x*r.y - l.y*r.x;
}

typedef pair<Point, int> pos;

bool operator<(pos l, pos r)
{
    Point a = l.first;
    Point b = r.first;
    if (a.x < b.x)
        return true;
    if (a.x == b.x && a.y < b.y)
        return true;
    return false;
}

struct PolarComparator {
    Point p0;
    PolarComparator(Point p) : p0(p) {}
    bool operator()(pos pl, pos pr)
    {
        Point a = pl.first - p0;
        Point b = pr.first - p0;
        if ((a^b) > 0)
            return true;
        if ((a^b) == 0 && a.length() < b.length())
            return true;
        return false;
    }
};

int main()
{
    freopen("polyline.in", "r", stdin);
    freopen("polyline.out", "w", stdout);
    int n;
    scanf("%d", &n);
    vector<pos> pts;

    for (int i=0; i<n; ++i) {
        int a, b;
        scanf("%d%d", &a, &b);
        pts.push_back(make_pair(Point(a, b), i+1));
    }

    vector<pos>::iterator f = min_element(pts.begin(), pts.end());

    swap(pts.front(), *f);
    sort(pts.begin()+1, pts.end(), PolarComparator(pts.front().first));
    int j = n-2;
    while (j >= 0 && ((pts[j].first - pts.front().first)^ (pts.back().first - pts.front().first)) == 0)
        --j;
    if (j == -1) {
        printf("0\n");
        return 0;
    }
    reverse(pts.begin()+j+1, pts.end());

    for (int i =0;i<n;++i) {
        printf((i == 0)?"%d":" %d", pts[i].second);
    }
    printf("\n");

    return 0;
}
